@@ -1,3 +1,4 @@
+import logging
 import botocore.client
 import boto3
 import boto3.session
@@ -51,6 +52,7 @@ class AWSClient():
         Args:
             role_arn (str, optional): Assume this IAM role first
             role_session_name (str, optional): Assumed role session name. Defaults to 'Session'.
+            set_as_detault (bool, optional): Set session as boto3
 
         kwargs: Additionnal arguments for boto3.sessions.Session
             region_name (str): AWS Region
@@ -64,6 +66,7 @@ class AWSClient():
             kwargs.update(self.assume_role(role_arn, role_session_name))
         session = boto3.session.Session(**kwargs)
         if set_as_detault:
+            logging.warning(f"Setting default boto3 session: {role_session_name} for {role_arn}")
             boto3.DEFAULT_SESSION = session
         return session
 
