@@ -21,13 +21,15 @@ log = logging.getLogger(__name__)
 class CostExplorer(base.AWSClient):
     __granularity: types.CAUGranularity = None
     __period: types.CAUTimePeriod = None
+    __metrics: types.CAUMetrics = None
 
     def __init__(
             self,
             *,
             role_arn: str=None,
             granularity: types.CAUGranularity='MONTHLY',
-            period:relativedelta=None,
+            metrics: types.CAUMetrics=['UnblendedCost', 'BlendedCost'],
+            period: relativedelta=None,
             date: datetime.datetime=None) -> None:
         """
         Helper to build an AWS Cost Explorer report (sets of CAU calls)
@@ -41,16 +43,21 @@ class CostExplorer(base.AWSClient):
         super().__init__()
         self.ce = self.client('ce', role_arn=role_arn)
         self.granularity = granularity.upper()
+        self.__metrics = metrics
         self._setup_period(date=date, period=period)
 
-    @property
-    def granularity(self) -> types.CAUGranularity:
-        return self.__granularity
-
     @property
     def period(self) -> types.CAUTimePeriod:
         return self.__period
 
+    @property
+    def metrics(self) -> types.CAUMetrics:
+        return self.__metrics
+
+    @property
+    def granularity(self) -> types.CAUGranularity:
+        return self.__granularity
+
     @granularity.setter
     def granularity(self, val: types.CAUGranularity):
         self.__granularity = val.upper()
@@ -81,7 +88,7 @@ class CostExplorer(base.AWSClient):
         )
         log.info(f"Start:{self.period['Start']} / End:{self.period['End']} / Granularity: {self.granularity}")
 
-    def get_cost_and_usage(self, **props) -> dict:
+    def get_cost_and_usage(self, **props: types.CostAndUsageAttributes) -> dict:
         """Recursively query CE to get cost (and usage) data
 
         Args:
@@ -92,12 +99,14 @@ class CostExplorer(base.AWSClient):
             GroupBy (list, optional): [description]. Defaults to None.
             NextPageToken (str, optional): [description]. Defaults to None.
         Returns:
-            dict: CE api results
+            dict: AWS Cost Explorer CAU api call response
         """
         if 'TimePeriod' not in props:
             props['TimePeriod'] = self.period
         if 'Granularity' not in props:
             props['Granularity'] = self.granularity
+        if 'Metrics' not in props:
+            props['Metrics'] = self.metrics
 
         log.info(f"get_cost_and_usage({props})")
         response = self.ce.get_cost_and_usage(**props)
