@@ -2,27 +2,37 @@ import typing
 
 CAUTimePeriod = typing.Dict[typing.Literal['Start', 'End'], str]
 CAUGranularity = typing.Literal['MONTHLY', 'DAILY', 'HOURLY']
+CAUGroupByType = typing.Literal['DIMENSION', 'TAG', 'COST_CATEGORY']
+CAUMetrics = typing.List[typing.Literal['AmortizedCost', 'BlendedCost', 'NetAmortizedCost', 'NetUnblendedCost', 'NormalizedUsageAmount', 'UnblendedCost', 'UsageQuantity']]
+
+CAUDimensions = typing.Literal['RECORD_TYPE', 'SERVICE', 'REGION', 'LINKED_ACCOUNT']
 
 # AWS CostExplorer API protos
-MatchOptions = typing.Literal['EQUALS', 'STARTS_WITH', 'ENDS_WITH', 'CONTAINS', 'CASE_SENSITIVE', 'CASE_INSENSITIVE']
-DimensionsKeys = typing.Literal['SERVICE', 'RECORD_TYPE', 'REGION']
-RECORD_TYPE_DIMENSIONS = ["Credit", "Refund", "Upfront", "Support"]
-# RECORD_TYPE_DIMENSIONS = typing.List[typing.Literal["Credit", "Refund", "Upfront", "Support"]]
-GroupByTypes = typing.Literal['TAG', 'DIMENSION']
-CAUMetrics = typing.List[typing.Literal['AmortizedCost', 'BlendedCost', 'NetAmortizedCost', 'NetUnblendedCost', 'NormalizedUsageAmount', 'UnblendedCost', 'UsageQuantity']]
 CAUFilter = typing.Dict[typing.Literal['Or', 'And', 'Not'], dict]
-CAUProps = dict(
-    Granularity=CAUGranularity,
-    TimePeriod=typing.Dict[typing.Literal['Start', 'End'], str],
-    Filter=CAUFilter,
-    Metrics=CAUMetrics,
-    GroupBy=list,
-    NextPageToken=str
-)
+CAUGroupBy = typing.List[typing.Dict[typing.Literal['Type', 'Key'], str]]
+
+
+# Cleanup
+MatchOptions = typing.Literal['EQUALS', 'STARTS_WITH', 'ENDS_WITH', 'CONTAINS', 'CASE_SENSITIVE', 'CASE_INSENSITIVE']
+CAU_RECORD_TYPE = typing.Literal["Credit", "Refund", "Upfront", "Support"]
+# RECORD_TYPE_DIMENSIONS = typing.List[typing.Literal["Credit", "Refund", "Upfront", "Support"]]
 
 # Set to Max history time CAU
 CAUDefaultPeriods = dict(
     HOURLY=dict(days=14),
     DAILY=dict(days=90),
     MONTHLY=dict(months=12)
-)
\ No newline at end of file
+)
+
+
+
+class CostAndUsageAttributes:
+    Granularity: CAUGranularity
+    TimePeriod: CAUTimePeriod
+    Filter: CAUFilter
+    Metrics: CAUMetrics
+    GroupBy: CAUGroupBy
+    NextPageToken: str
+
+    def __init__(self) -> None:
+        pass
